summaryrefslogtreecommitdiffstats
path: root/kexi/widget/tableview/kexicelleditorfactory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/widget/tableview/kexicelleditorfactory.h')
-rw-r--r--kexi/widget/tableview/kexicelleditorfactory.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kexi/widget/tableview/kexicelleditorfactory.h b/kexi/widget/tableview/kexicelleditorfactory.h
index 26b48bb6..06795ac0 100644
--- a/kexi/widget/tableview/kexicelleditorfactory.h
+++ b/kexi/widget/tableview/kexicelleditorfactory.h
@@ -51,10 +51,10 @@ class KEXIDATATABLE_EXPORT KexiCellEditorFactory
If still no item found, the default is tried. Eventually, may return NULL. */
static KexiCellEditorFactoryItem* item( uint type, const TQString& subType = TQString() );
-// static KexiTableEdit* createEditor(KexiDB::Field &f, TQScrollView* tqparent = 0);
- /*! Creates a new editor for \a column. If \a tqparent is of TQScrollView, the new editor
- will be created inside tqparent->viewport() instead. */
- static KexiTableEdit* createEditor(KexiTableViewColumn &column, TQWidget* tqparent = 0);
+// static KexiTableEdit* createEditor(KexiDB::Field &f, TQScrollView* parent = 0);
+ /*! Creates a new editor for \a column. If \a parent is of TQScrollView, the new editor
+ will be created inside parent->viewport() instead. */
+ static KexiTableEdit* createEditor(KexiTableViewColumn &column, TQWidget* parent = 0);
protected:
static void init();
@@ -69,8 +69,8 @@ class KEXIDATATABLE_EXPORT KexiCellEditorFactoryItem
TQString className() { return m_className; }
protected:
-// virtual KexiTableEdit* createEditor(KexiDB::Field &f, TQScrollView* tqparent = 0) = 0;
- virtual KexiTableEdit* createEditor(KexiTableViewColumn &column, TQWidget* tqparent = 0) = 0;
+// virtual KexiTableEdit* createEditor(KexiDB::Field &f, TQScrollView* parent = 0) = 0;
+ virtual KexiTableEdit* createEditor(KexiTableViewColumn &column, TQWidget* parent = 0) = 0;
TQString m_className;
friend class KexiCellEditorFactory;